@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -21,9 +21,7 @@ SieveEditorCentralWidget::SieveEditorCentralWidget(QWidget *parent, KActionColle
     setCurrentWidget(mConfigureWidget);
 }
 
-SieveEditorCentralWidget::~SieveEditorCentralWidget()
-{
-}
+SieveEditorCentralWidget::~SieveEditorCentralWidget() = default;
 
 void SieveEditorCentralWidget::slotServerSieveFound(bool hasServer)
 {
